/*
        Danilo Djokic <djokicd@outlook.com>
        Applied Physics and Electronics - Petnica Science Center
        http://ele.petnica.rs/
        Date: 17/9/2015

  - Project name:
     Camera click demo
  
  - Description:
     This project is a implementation of camera click on PIC32.
     Only half of the image is shown because of memory limitations of the microcontroller.
     
  - Test configuration:
     MCU:             PIC32MX460F512L
                      https://www.google.rs/search?q=PIC32MX460F512L&ie=&oe=
     Dev.Board:       EasyPIC Fusion v7
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.000MHz
     ext. modules:    camera click board  - 
                      http://www.mikroe.com/click/camera/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
 * NOTES:
     - Place Camera click board in the mikroBUS socket 1.
     - Turn on TFT backlight on SW11.
 */


int x;
int cnt;
char str[16];

#include "resources.h"
#include "CameraDriver.c"

void InitMCU()
{
  AD1PCFG = 0xFFFF;
  JTAGEN_bit = 0;
  TFT_Set_Default_Mode();
  TFT_Init(320, 240);
  
  TFT_Fill_Screen( CL_BLACK );
  
  delay_ms(10);
  
  SPI2_Init_Advanced(_SPI_MASTER,_SPI_8_BIT, 6, _SPI_SS_DISABLE,_SPI_DATA_SAMPLE_MIDDLE,_SPI_CLK_IDLE_LOW,_SPI_ACTIVE_2_IDLE);
  
  Chip_Select_Dir = 0; // Output;
  Ready_Pin_Dir = 1; // Input;
  Chip_Select = 1; // Deselect all;
  
  delay_ms(1000);
}

void DrawFrame() {  // Drawing the frame
  TFT_Set_Ext_Buffer(Get_Camera_Data);
  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_RED, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_Line(20,  46, 300,  46);
  TFT_Set_Font(TFT_defaultFont , CL_GREEN, FO_HORIZONTAL);
  TFT_Write_Text("Camera  Click  Board  PIC32 Demo", 42, 14);
  TFT_Set_Font(TFT_defaultFont , CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyPIC Fusion v7", 19, 223);
  TFT_Set_Font(TFT_defaultFont , CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("ele.petnica.rs", 200, 223);
  
  TFT_image(0, 0, pfepetnica, 1);
  
  delay_ms(100);
}

void main() {
  InitMCU();
  
  DrawFrame();

  while(1==1){

        TFT_Ext_Image(72, 61, 0, 1); // Drawing image on (72, 61)
  }
}