#define QCIF_WIDTH  176
#define QCIF_HEIGHT 144
#define CIF_WIDTH   352
#define CIF_HEIGHT  288
#define QVGA_WIDTH  320
#define QVGA_HEIGHT 240
#define VGA_WIDTH   640
#define VGA_HEIGHT  480
#define FRM_WIDTH   QCIF_WIDTH
#define FRM_HEIGHT  QCIF_HEIGHT

char *Get_Camera_Data(unsigned long offset, unsigned long count, unsigned long *num);

// camera commands
const unsigned char __CMD_WRITE_REG = 2;
const unsigned char __CMD_READ_REG = 3;
const unsigned char __CMD_GET_FRAME = 4;
const unsigned char __CMD_GET_FRAME_BUFFERED = 5;
const unsigned char __CMD_SET_ROW_NUM = 6;
const unsigned char __CMD_SET_ROW_SIZE = 7;

// BMP header to display only half of the image.
unsigned char bmpHeader[10] = {0x00, 0x10, (FRM_HEIGHT/2), (FRM_HEIGHT/2)>>8, FRM_WIDTH, (FRM_WIDTH)>>8, 0xFF, 0xFF, 0xFF, 0xFF}; // Header of BMP in QVGA format.
unsigned char frmBuff[FRM_WIDTH*FRM_HEIGHT];

unsigned long bPos;

// Send command to camera via SPI
void SendCommand(unsigned char cmd) {
  while(Ready_Pin == 0)
    ;
  SPI2_Write(cmd);
}

// Read bytes from camera via SPI
void ReadBytes(unsigned char *ptr, unsigned long num) {
  while(num){
    num--;
    while(Ready_Pin == 0)
      ;
    *ptr = SPI2_Read(0);
    *ptr++;
  }
}

// Send bytes to camera via SPI
void SendBytes(unsigned char *ptr, unsigned long num) {
  while(num){
    num--;
    while(Ready_Pin == 0)
      ;
    SPI2_Write(*ptr);
    *ptr++;
  }
}

// Read from camera registers via SPI
unsigned char ReadReg(unsigned char regNum, unsigned char *regVal) {
  unsigned int status;

  SendCommand(__CMD_READ_REG);
  SendBytes(&regNum, 1);
  ReadBytes(&status, 2);
  *regVal = status & 0xFF;
  return status >> 8;
}

// Write to camera registers via SPI
unsigned char WriteReg(unsigned char regNum, unsigned char regVal){
  unsigned int rv;
  unsigned char status;
  SendCommand(__CMD_WRITE_REG);
  rv = regNum | (regVal << 8);
  SendBytes(&rv, 2);
  ReadBytes(&status, 1);
  return status;
}

int i;

// Get image data from camera
char* Get_Camera_Data(unsigned long offset, unsigned long count, unsigned long *num) {
  unsigned char* resPtr;
  *num = count;
  Chip_Select = 0;
  if(count == 10){
    *num = 10;
    bPos = 0;
    SendCommand(__CMD_GET_FRAME_BUFFERED);
    
    ReadBytes(frmBuff, FRM_WIDTH*FRM_HEIGHT); // This line appears twice because there isn't enough RAM on PIC32MX460F512L to store the entire image.
    ReadBytes(frmBuff, FRM_WIDTH*FRM_HEIGHT); // So, only the bottom half of the image is displayed.

    
    return &bmpHeader[0];
  }
  Chip_Select = 1;
  resPtr = &frmBuff[bPos];
  bPos = bPos + FRM_WIDTH*2;
  return resPtr;
}